@@ -1,7 +1,6 @@
 ########################################################################################################################
 ## Fonction calculant la vraisemblance completee integree en zMAP (ICL exact)
 ########################################################################################################################
-
 ## fonction outils
 logdinvgamma <- function(x, alpha, beta)
   alpha*log(beta) - lgamma(alpha) - (alpha+1)*log(x) - beta/x
@@ -15,9 +14,8 @@ IntegreOneVariableContinuous <- function(x, priors){
   n <- length(x)
   n1 <- n + n0
   s1 <- sqrt( sum((x-mean(x))**2) + s0**2 + ((mu - mean(x))**2)/(1/n0 + 1/n) )
-  # theta1 <- (n0*mu + n*mean(x))/n1
-  integre <- -log(sqrt(pi))*n + lgamma((n + nu)/2) - lgamma(nu/2) +   nu * log(s0/s1) - n*log(s1) + log(sqrt(n0 / n1) )
-  return(integre)
+  -log(sqrt(pi))*n + lgamma((n + nu)/2) - lgamma(nu/2) +   nu * log(s0/s1) - n*log(s1) + log(sqrt(n0 / n1) )
+
 }
 ## Integrale sur une variable integer pour 1 classe ou non discriminante
 IntegreOneVariableInteger <- function(x, priors){
@@ -27,6 +25,46 @@ IntegreOneVariableInteger <- function(x, priors){
   return(integre)
 }
 
+## Integrale sur une variable categorielle pour 1 classe ou non discriminante
+IntegreOneVariableCategorical <- function(eff) lgamma(length(eff) * 0.5) - length(eff) * lgamma(0.5) + sum(lgamma(eff + 0.5)) - lgamma(sum(eff + 0.5))
+
+## ICL exact dans le cas de variables mixed
+pvdiscrim <- function(obj){
+  out <- rep(0, obj@data@d)
+  repere <- 0
+  if (obj@data@withContinuous){
+    for (j in 1:obj@data@dataContinuous@d){
+      repere <- repere + 1
+      out[repere] <- sum(sapply(1:obj@model@g, function(k) IntegreOneVariableContinuous(obj@data@dataContinuous@data[which( (obj@partitions@zMAP==k)*obj@data@dataContinuous@notNA[,j] ==1),j], obj@data@dataContinuous@priors[j,]))) - IntegreOneVariableContinuous(obj@data@dataContinuous@data[which(obj@data@dataContinuous@notNA[,j]==1),j], obj@data@dataContinuous@priors[j,])
+      names(out)[repere] <- colnames(obj@data@dataContinuous@data)[j]
+    }
+  }
+  if (obj@data@withInteger){
+    for (j in 1:obj@data@dataInteger@d){
+      repere <- repere + 1
+      out[repere] <- sum(sapply(1:obj@model@g, function(k) IntegreOneVariableInteger(obj@data@dataInteger@data[which( (obj@partitions@zMAP==k)*obj@data@dataInteger@notNA[,j] ==1),j], obj@data@dataInteger@priors[j,]))) - IntegreOneVariableInteger(obj@data@dataInteger@data[which(obj@data@dataInteger@notNA[,j]==1),j], obj@data@dataInteger@priors[j,])
+      names(out)[repere] <- colnames(obj@data@dataInteger@data)[j]
+    }
+  }
+  if (obj@data@withCategorical){
+    who <- which(names(obj@model@omega) %in% colnames(obj@data@dataCategorical@shortdata))
+    for (loc in 1:obj@data@dataCategorical@d){
+      repere <- repere + 1
+      names(out)[repere] <- colnames(obj@data@dataCategorical@data)[loc]
+      eff <- table(obj@data@dataCategorical@data[,loc])
+      out[repere] <-  -IntegreOneVariableCategorical(eff)
+      
+      for (k in 1:obj@model@g){
+        for (h in 1:length(eff))  eff[h] <- sum(obj@data@dataCategorical@data[which(obj@partitions@zMAP == k),loc] == obj@data@dataCategorical@modalitynames[[loc]][h], na.rm = T)
+        out[repere] <- out[repere]  + IntegreOneVariableCategorical(eff)
+      }
+    }    
+  }
+  return(out)
+}
+
+
+
 ## ICL exact dans le cas de variables continues
 ICLcontinuous <- function(obj){
   ICLexact <- lgamma(obj@model@g/2) - obj@model@g*lgamma(1/2) + 
@@ -60,11 +98,6 @@ ICLinteger <- function(obj){
 }
 
 
-## Integrale sur une variable categorielle pour 1 classe ou non discriminante
-IntegreOneVariableCategorical <- function(eff)
-  return(lgamma(length(eff) * 0.5) - length(eff) * lgamma(0.5) + sum(lgamma(eff + 0.5)) - lgamma(sum(eff + 0.5)))
-
-
 ## ICL exact dans le cas de variables categorielles
 ICLcategorical <- function(obj){
   ICLexact <- lgamma(obj@model@g/2) - obj@model@g*lgamma(1/2) + sum(lgamma(table(c(1:obj@model@g, obj@partitions@zMAP)) - 1/2)) - lgamma(obj@data@n + obj@model@g/2)
@@ -139,4 +172,5 @@ ICLmixed <- function(obj){
   }
   names(ICLexact) <- NULL
   return(ICLexact)
-}
\ No newline at end of file
+}
+
